function [ddp,dL] = Controller(p,dp,L,Lr,ref,Phi)

%inputs
phix = Phi(1); dphix = Phi(2);
phiy = Phi(3); dphiy = Phi(4);
x0 = p(1); dx0 = dp(1); 
y0 = p(2); dy0 = dp(2); 
z0 = p(3); dz0 = dp(3);


%Initial values
g = 9.81;
omega0 = sqrt(g/L);
zeta = 1/sqrt(2);
omegaXY = omega0*0.1;

%Control gains
Kp = omegaXY^2; Kd=2*zeta*omegaXY;

rx = ref(1);
ry = ref(2);
rz = ref(3);

%Abbreviations
w0 = omega0;
sx = sin(phix);
sy = sin(phiy);
cy = cos(phiy);

%Damping
ddy0 = 2*L*zeta*w0*dphix - Kp*(y0-ry) - Kd*dy0;
ddx0 = - 2*L*zeta*w0*dphiy - (1/cy)*sx*sy*ddy0 - Kp*(x0-rx) - Kd*dx0;
ddz0 = -Kp*(z0-rz) - Kd*dz0;

dL   = -4*Kp*(L-Lr);
ddp=[ddx0,ddy0,ddz0]';