function dydt = SphericalCrane(t,y,plot)

%Initial Values
L = 1;
g = 9.81;
omega0 = sqrt(g/L);
zeta = 0.7;
omegaXY = omega0*0.1;

%Control Gains
 Kp = .75; Kd = .25;
%  Kp = omegaXY^2; Kd=2*zeta*omegaXY;

%Trajectories
 rx = 2.5+0*t; ry = -2.5+0*t;
%  rx = 0.5*sin(0.15*t); ry = 0.5*cos(0.15*t); 

%Inputs
phix = y(1); dphix = y(2);
phiy = y(3); dphiy = y(4);
x0 = y(5); dx0 = y(6); 
y0 = y(7); dy0 = y(8); 

%Abbreviations
sx = sin(phix);
cx = cos(phix);
sy = sin(phiy);
cy = cos(phiy);
w0 = omega0;

%Damping
ddy0 = 2*L*zeta*w0*dphix - Kp*(y0-ry) - Kd*dy0;
ddx0 = - 2*L*zeta*w0*dphiy - (1/cy)*sx*sy*ddy0 - Kp*(x0-rx) - Kd*dx0;

%Equations of Motion
dydt = [ dphix;
         (1/cy) * (2*dphix*dphiy*sy - (1/L)*ddy0*cx- w0^2*sx);
         dphiy;
          - dphix^2*sy*cy + (1/L)*ddx0*cy + (1/L)*ddy0*sx*sy - w0^2*cx*sy;
         dx0;
         ddx0;         
         dy0;
         ddy0];

%For Trajectories
if plot == 'p'
    dydt(1) = rx;
    dydt(2) = ry;
end

% if plot == 's'
%     dydt(1) = ry;
% end
