clear all

%Initial Angles
phix0=  deg2rad(5); 
phiy0=  deg2rad(-10); 

%Simulation Time
T0 = 100;

%Accuracy of numerical integration
options = odeset('RelTol',1e-9);

%ODE-Function
[t,y] = ode45('SphericalCrane',[0 T0],[phix0; 0; phiy0; 0; 0; 0; 0; 0],options);

%Reference Angle
rphi = 0*t;

%Plots
figure(1); plot(t,rad2deg(y(:,1)),t,rad2deg(y(:,3)));
grid; legend('$\phi_x$','$\phi_y$','Interpreter','latex','location','southeast','FontSize',14);
axis([0 50 -10 10]);
xlabel('Time, [s]'); ylabel('Angle, [deg]');

figure(2); clf;
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCrane(t(i),y(i,:),'p');
end
rx = yplot(:,1);
ry = yplot(:,2);
plot(t,y(:,5),t,y(:,7),t,rx, '--',t,ry,'--');
axis([0 100 -6 6]);
grid; legend('$x_0$','$y_0$','Interpreter','latex','location','southeast','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');

 
