clear variables

%Initial conditions on position
phix0 =  deg2rad(5); 
phiy0 =  deg2rad(-10); 

%Accuracy of numerical integration
options = odeset('RelTol',1e-9);

%Simulation Time
T0=100;

%ODE-Function
[t,y] = ode45('SphericalCraneXY',[0 T0],[phix0; 0; phiy0; 0; 0; 0; 0; 0],options);

%Angle Reference
rphi=0*t;

%Plots
figure(1); plot(t,rad2deg(y(:,1)),t,rphi,'--r');
grid; legend('\phi_x','location','southeast');
xlabel('Time, [s]'); ylabel('Angle, [Deg]');

figure(2); plot(t,rad2deg(y(:,3)),t,rphi,'--r');
grid; legend('$\phi_x$','$\phi_y$','Interpreter','latex','location','southeast','FontSize',14);
xlabel('Time, [s]'); ylabel('Angle, [Deg]');

figure(3); clf;
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCraneXY(t(i),y(i,:),'p');
end
r = yplot(:,1);
plot(t,y(:,5),t,r, '--r'); 
axis([0 100 -1.4 1]);
grid; legend('$x_0$','Interpreter','latex','location','southeast','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');

figure(4); clf; 
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCraneXY(t(i),y(i,:),'s');
end
r = yplot(:,1);
plot(t,y(:,7),t,r, '--r');
axis([0 100 -1 1]);
grid; legend('$y_0$','Interpreter','latex','location','southeast','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');

 
