clear variables

%Initial Angles
phix0 =  deg2rad(5); 
phiy0 =  deg2rad(-10); 

%Accuracy of Numerical Integration
options = odeset('RelTol',1e-9);

%Simulation Time
T0=100;

%ODE-Function
[t,y] = ode45('SphericalCraneXYZ',[0 T0],[phix0; 0; phiy0; 0; 0; 0; 0; 0; 0; 0],options);

%Angle Reference
rphi=0*t;

%Plots
figure(1); plot(t,rad2deg(y(:,1)),t,rad2deg(y(:,3)));
grid; legend('$\phi_x$','$\phi_y$','location','southeast','Interpreter','latex','FontSize',14);
 axis([0 50 -10 10]);
xlabel('Time, [s]'); ylabel('Angle, [deg]');

figure(2); clf;
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCraneXYZ(t(i),y(i,:),'p');
end
r = yplot(:,1);
plot(t,y(:,5),t,r,'--');
axis([0 100 -1.4 1]);
grid; legend('$x_0$','location','southeast','Interpreter','latex','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');

figure(3); clf;
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCraneXYZ(t(i),y(i,:),'s');
end
r = yplot(:,1);
plot(t,y(:,7),t,r,'--');
axis([0 100 -1 1]);
grid; legend('$y_0$','location','southeast','Interpreter','latex','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');

figure(4); clf; 
n = length(t); r = zeros(n,1);
for i = 1:n
    yplot(i,:) = SphericalCraneXYZ(t(i),y(i,:),'t');
end
r = yplot(:,1);
plot(t,y(:,9),t,r,'--');
axis([0 100 -1 1]);
grid; legend('$z_0$','location','southeast','Interpreter','latex','FontSize',14);
xlabel('Time, [s]'); ylabel('Position, [m]');
 
